@@ -8,6 +8,9 @@
  * 			Theodore Ts'o, tytso@mit.edu, 1/1/93
  *
  * Last modified: [tytso:19940520.0036EDT]
+ *
+ * added in support for the mc68000 kernel for debian
+ *  Gordon Russell <g.russell@dcs.napier.ac.uk>
  */
 
 #include <stdio.h>
@@ -43,6 +46,16 @@ struct serial_type_struct {
 #ifdef PORT_16650
 	PORT_16650,	"16650",
 #endif
+#ifdef __mc68000__
+         SER_SCC_NORM,   "SCC w/o DMA",
+         SER_SCC_DMA,    "SCC w/ DMA",
+         SER_MFP_CTRL,   "MFP",
+         SER_MFP_BARE,   "MFP w/o ctrl lines",
+         SER_MIDI,       "MIDI",
+         SER_AMIGA,      "Amiga builtin",
+         SER_IOEXT,      "GVP IO-Extender (16c552)",
+         SER_MFC_III,    "BSC MultiFaceCard III",
+#endif  /* __mc68000__ */
 	PORT_UNKNOWN,	"none",
 	-1,		NULL
 };
@@ -368,8 +381,8 @@ void set_serial(char *device, char ** arg)
 	
 
 	if ((fd = open(device, O_RDWR|O_NONBLOCK)) < 0) {
-		if (verbosity==0 && errno==ENOENT)
-			exit(201);
+		if (verbosity==0 && (errno==ENOENT ||errno==ENODEV))
+			return;
 		perror(device);
 		exit(201);
 	}
